@@ -90,7 +90,8 @@ class Logging:
         # a Time key for each new letter, and a new sorter argument must be
         # added to self.sort. All of these dictionary items begin as lists,
         # and are converted to np.arrays or astropy.time.Times in self.sort.
-        self.data = {'dDesign': [], 'dTime': [], 'dConfig': [], 'cLead': []}
+        self.data = {'dField': [], 'dTime': [], 'dConfig': [], 'cLead': [],
+                     "dDesign": []}
         self.ap_data = {'dDesign': [], "dConfig": [], 'dTime': [],
                         'iTime': [], 'iID': [],
                         'iSeeing': [], 'iDetector': [], 'iDither': [],
@@ -99,12 +100,14 @@ class Logging:
                         'fDesign': [], 'fTime': [], 'fMissing': [], 'fFaint': [],
                         'fNMissing': [], 'fNFaint': [], 'fRatio': [], 'aTime': [],
                         'aOffset': [], 'aID': [], 'aLamp': [], 'oTime': [],
-                        'oOffset': [], 'oDither': []}
-        self.b_data = {'dDesign': [], "dConfig": [], 'dTime': [],
+                        'oOffset': [], 'oDither': [], "dField": [],
+                        "iField": [], "fField": []}
+        self.b_data = {'dDesign': [], "dConfig": [], 'dTime': [], "dField": [],
                        'iTime': [], 'iID': [],
                        'iDetector': [], 'iDither': [],
-                       'iEType': [], 'idt': [], 'iDesign': [], 'iHart': [],
-                       'iDesign': [], "iConfig": [], 'hHart': [], 'hTime': []}
+                       'iEType': [], 'idt': [], 'iField': [], 'iHart': [],
+                       'iDesign': [], "iConfig": [], 'hTime': [],
+                       "hField": []}
         # These values are not known from the header and must be created
         # after self.sort. N for number, AP or B for APOGEE or BOSS, and NSE
         # for BOSS dithers, and AB for APOGEE dithers, dt for boss exposure
@@ -114,7 +117,6 @@ class Logging:
                             'dNBE': [], 'dNBC': [], 'dBdt': [], 'dNB': [],
                             'dAPSummary': [],
                             'dBSummary': []}
-        self.test_procs = []
         master_path = (Path(apogee_data.__file__).absolute().parent.parent
                        / "dat/master_dome_flat.fits.gz")
         if not master_path.exists():
@@ -124,6 +126,12 @@ class Logging:
         self.ap_master = np.median(master_data[:, 550:910], axis=1)
         self.morning_filter = None
         self.ap_image = None
+        
+        self.support = multiprocessing.Manager().dict()
+        self.support["offsets"] = ""
+        self.support["focus"] = ""
+        self.support["weather"] = ""
+        self.support["hartmann"] = ""
 
     def ap_test(self, img):
         """Calls aptest on hub, this could certainly be replaced in the near
@@ -161,6 +169,7 @@ class Logging:
         self.ap_data['fFaint'].append(faint)
         self.ap_data['fRatio'].append(flux_ratio)
         self.ap_data['fDesign'].append(img.design_id)
+        self.ap_data['fField'].append(img.field_id)
         self.ap_data['fTime'].append(img.isot)
 
     def parse_images(self):
@@ -170,8 +179,6 @@ class Logging:
             print('Reading APOGEE Data ({})'.format(len(self.ap_images)))
             img = None
             for image in tqdm(self.ap_images):
-                if self.args.verbose:
-                    print(image.name)
                 img = apogee_data.APOGEERaw(image, self.args, 1)
                 # img.parse_layer(1)
                 if img.lead is None:  # If the first exposure is still
@@ -181,7 +188,6 @@ class Logging:
                     continue
                 if (img.exp_type == 'Domeflat') and ('-a-' in img.file.name):
                     self.ap_test(img)
-                    self.test_procs.append(img.design_id)
                 elif ('Arc' in img.exp_type) and ('-a-' in img.file.name):
                     self.ap_data['aTime'].append(img.isot)
                     self.ap_data['aID'].append(img.exp_id)
@@ -191,7 +197,7 @@ class Logging:
                         self.ap_data['aLamp'].append('ThAr')
                     elif 'UNe' in img.exp_type:
                         self.ap_data['aOffset'].append(
-                            img.compute_offset((60, 70), 1180, 30, 3))
+                            img.compute_offset((60, 70), 1190, 30, 3))
                         self.ap_data['aLamp'].append('UNe')
                     else:
                         print("Couldn't parse the arc image: {} with exposure"
@@ -203,33 +209,36 @@ class Logging:
                     # input)
                     self.ap_data['oTime'].append(img.isot)
                     self.ap_data['oOffset'].append(
-                        img.compute_offset((30, 35), 1090, 40, 2))
+                        # img.compute_offset((30, 35), 1090, 40, 2))
+                        img.compute_offset((30, 35), 1100, 40, 2))
                     self.ap_data['oDither'].append(img.dither)
 
-                if img.design_id not in self.data['dDesign']:
-                    self.data['dDesign'].append(img.design_id)
-                    self.data['dConfig'].append(img.config_id)
+                if img.field_id not in self.data['dField']:
+                    self.data['dField'].append(img.field_id)
+                    self.data['dDesign'].append(set([img.design_id]))
+                    self.data['dConfig'].append(set([img.config_id]))
                     self.data['dTime'].append(img.isot)
                     try:
                         self.data['cLead'].append(img.lead)
                     except AttributeError:
                         self.data["cLead"].append("")
                 else:
-                    i = self.data['dDesign'].index(img.design_id)
+                    i = self.data['dField'].index(img.field_id)
                     # If a design has multiple configs, take the lowest (first)
-                    self.data["dConfig"][i] = min(self.data["dConfig"][i],
-                                                  img.config_id)
+                    self.data["dDesign"][i].add(img.design_id)
+                    self.data["dConfig"][i].add(img.config_id)
                     if img.isot < self.data['dTime'][i]:
                         self.data['dTime'].pop(i)
                         self.data['dTime'].insert(i, img.isot)
-                if img.design_id not in self.ap_data['dDesign']:
-                    self.ap_data['dDesign'].append(img.design_id)
-                    self.ap_data['dConfig'].append(img.config_id)
+                if img.field_id not in self.ap_data['dField']:
+                    self.ap_data['dField'].append(img.field_id)
+                    self.ap_data['dDesign'].append(set([img.design_id]))
+                    self.ap_data['dConfig'].append(set([img.config_id]))
                     self.ap_data['dTime'].append(img.isot)
                 else:
-                    i = self.ap_data['dDesign'].index(img.design_id)
-                    self.ap_data["dConfig"][i] = min(self.ap_data["dConfig"][i],
-                                                     img.config_id)
+                    i = self.ap_data['dField'].index(img.field_id)
+                    self.ap_data["dDesign"][i].add(img.design_id)
+                    self.ap_data["dConfig"][i].add(img.config_id)
                     if img.isot < self.ap_data['dTime'][i]:
                         self.ap_data['dTime'].pop(i)
                         self.ap_data['dTime'].insert(i, img.isot)
@@ -268,6 +277,7 @@ class Logging:
                 self.ap_data['iNRead'].append(img.n_read)
                 self.ap_data['iEType'].append(img.exp_type)
                 self.ap_data['iDesign'].append(img.design_id)
+                self.ap_data["iField"].append(img.field_id)
                 self.ap_data['iConfig'].append(img.config_id)
             if img is not None:
                 self.ap_image = img
@@ -275,29 +285,31 @@ class Logging:
             print('Reading BOSS Data ({})'.format(len(self.b_images)))
             for image in tqdm(self.b_images):
                 img = boss_data.BOSSRaw(image)
-                if img.design_id not in self.data['dDesign']:
-                    self.data['dDesign'].append(img.design_id)
-                    self.data['dConfig'].append(img.config_id)
+                if img.field_id not in self.data['dField']:
+                    self.data['dField'].append(img.field_id)
+                    self.data['dDesign'].append(set([img.design_id]))
+                    self.data['dConfig'].append(set([img.config_id]))
                     try:
                         self.data['cLead'].append(img.lead)
                     except AttributeError:
                         self.data["cLead"].append("")
                     self.data['dTime'].append(img.isot)
                 else:
-                    i = self.data['dDesign'].index(img.design_id)
-                    self.data["dConfig"][i] = min(self.data["dConfig"][i],
-                                                  img.config_id)
+                    i = self.data['dField'].index(img.field_id)
+                    self.data["dDesign"][i].add(img.design_id)
+                    self.data["dConfig"][i].add(img.config_id)
                     if img.isot < self.data['dTime'][i]:
                         self.data['dTime'].pop(i)
                         self.data['dTime'].insert(i, img.isot)
-                if img.design_id not in self.b_data['dDesign']:
-                    self.b_data['dDesign'].append(img.design_id)
-                    self.b_data["dConfig"].append(img.config_id)
+                if img.field_id not in self.b_data['dField']:
+                    self.b_data['dField'].append(img.field_id)
+                    self.b_data["dDesign"].append(set([img.design_id]))
+                    self.b_data["dConfig"].append(set([img.config_id]))
                     self.b_data['dTime'].append(img.isot)
                 else:
-                    i = self.b_data['dDesign'].index(img.design_id)
-                    self.b_data["dConfig"][i] = min(self.b_data["dConfig"][i],
-                                                    img.config_id)
+                    i = self.b_data['dField'].index(img.field_id)
+                    self.b_data["dDesign"][i].add(img.config_id)
+                    self.b_data["dConfig"][i].add(img.config_id)
                     if img.isot < self.b_data['dTime'][i]:
                         self.b_data['dTime'].pop(i)
                         self.b_data['dTime'].insert(i, img.isot)
@@ -309,33 +321,12 @@ class Logging:
                 self.b_data['idt'].append(img.exp_time)
                 self.b_data['iDesign'].append(img.design_id)
                 self.b_data['iHart'].append(img.hartmann)
+                if img.hartmann == "Left":
+                    self.b_data["hTime"].append(img.isot)
+                    self.b_data["hField"].append(img.field_id)
                 self.b_data['iConfig'].append(img.config_id)
+                self.b_data["iField"].append(img.field_id)
 
-                # if img.hartmann == 'Left' and self.telemetry:
-                #     # Note that times are sent in UTC and received in local, yet
-                #     # those times are marked as UTC
-                #     tstart = Time(img.isot).datetime
-                #     tend = (Time(img.isot) + 5 / 24 / 60).datetime
-                #     hart = self.telemetry.get([
-                #         '25m:hartmann:r1PistonMove',
-                #         # '25m:hartmann:r2PistonMove',
-                #         '25m:hartmann:b1RingMove',
-                #         # '25m:hartmann:b2RingMove',
-                #         '25m:hartmann:sp1AverageMove',
-                #         # '25m:hartmann:sp2AverageMove',
-                #         '25m:hartmann:sp1Residuals:steps',
-                #         '25m:hartmann:sp1Residuals:deg',
-                #         # '25m:hartmann:sp2Residuals:deg',
-                #         '25m:boss:sp1Temp:median',
-                #         # '25m:boss:sp2Temp:median',
-                #         # '25m:hartmann:sp2Residuals:steps'
-                #     ],
-                #         start=tstart,
-                #         end=tend,
-                #         interpolation='raw', scan_archives=False)
-
-                #     self.b_data['hHart'].append(hart)
-                #     self.b_data['hTime'].append(img.isot)
                 sos_files = []
                 # img_mjd = int(Time(img.isot).mjd)
                 # All boss exposures write as splog, but manga writes different
@@ -386,6 +377,9 @@ class Logging:
                         self.ap_data[key] = Time(item)
                     except ValueError:
                         self.ap_data[key] = Time(item, format='isot')
+                    except AttributeError:
+                        print(f"Could not read key {key} as time\n"
+                              f"{self.ap_data[key]}")
                 else:
                     self.ap_data[key] = np.array(item)
             ap_design_sorter = self.ap_data['dTime'].argsort()
@@ -450,43 +444,27 @@ class Logging:
                     self.b_data[key] = item[b_h_sorter]
 
     def count_dithers(self):
-        for i, design in enumerate(self.data['dDesign']):
+        for i, field in enumerate(self.data['dField']):
             self.design_data["dNAPA"].append(np.sum(
-                (self.ap_data['iDesign'] == design)
+                (self.ap_data['iField'] == field)
                 & (self.ap_data['iDither'] == 'A')
                 & (self.ap_data['iEType'] == 'Object')))
             self.design_data["dNAPB"].append(np.sum(
-                (self.ap_data['iDesign'] == design)
+                (self.ap_data['iField'] == field)
                 & (self.ap_data['iDither'] == 'B')
                 & (self.ap_data['iEType'] == 'Object')))
-            # self.design_data["dNBN'].append(np.sum(
-            # (self.b_data['iDesign'] == design)
-            # & (self.b_data['iDither'] == 'N')
-            # & (self.b_data['iEType'] == 'Science')))
-            # self.design_data["dNBS'].append(np.sum(
-            # (self.b_data['iDesign'] == design)
-            # & (self.b_data['iDither'] == 'S')
-            # & (self.b_data['iEType'] == 'Science')))
-            # self.design_data["dNBE'].append(np.sum(
-            # (self.b_data['iDesign'] == design)
-            # & (self.b_data['iDither'] == 'E')
-            # & (self.b_data['iEType'] == 'Science')))
-            # self.design_data["dNBC'].append(np.sum(
-            # (self.b_data['iDesign'] == design)
-            # & (self.b_data['iDither'] == 'C')
-            # & (self.b_data['iEType'] == 'Science')))
             self.design_data["dNB"].append(np.sum(
-                (self.b_data['iDesign'] == design)
+                (self.b_data['iField'] == field)
                 & (self.b_data['iEType'] == 'Science')))
             if self.design_data["dNB"][-1] != 0:
                 self.design_data["dBdt"].append(np.max(
                     self.b_data['idt'][
-                        (self.b_data['iDesign'] == design)
+                        (self.b_data['iField'] == field)
                         & (self.b_data['iEType'] == 'Science')]))
             else:
                 self.design_data["dBdt"].append(0)
 
-        for i, design in enumerate(self.data['dDesign']):
+        for i, field in enumerate(self.data['dField']):
             """To determine the number of apogee a dithers per design (cNAPA),
             as well as b dithers (cNAPB), and the same for NSE dithers."""
             # APOGEE dithers
@@ -500,19 +478,6 @@ class Logging:
                 self.design_data['dAPSummary'].append(
                     '{}xA {}xB'.format(self.design_data["dNAPA"][i],
                                        self.design_data["dNAPB"][i]))
-            # BOSS (MaNGA) dithers
-            # if self.design_data["dNBC'][i] == 0:
-            # if (self.design_data["dNBN'][i]
-            # == self.design_data["dNBS'][i]
-            # == self.design_data["dNBE'][i]):
-            # self.design_data['dBSummary'].append(
-            # '{}xNSE'.format(self.design_data["dNBN'][i]))
-            # else:
-            # self.design_data['dBSummary'].append(
-            # '{}xN {}xS {}xE'.format(self.design_data["dNBN'][i],
-            # self.design_data["dNBS'][i],
-            # self.design_data["dNBE'][i]))
-            # else:
             if self.design_data["dNB"][i] != 0:
                 self.design_data["dBSummary"].append(
                     '{}x{}s'.format(self.design_data["dNB"][i],
@@ -520,37 +485,38 @@ class Logging:
             else:
                 self.design_data['dBSummary'].append('No BOSS')
 
-    @staticmethod
-    def hartmann_parse(hart):
-        output = '{}\n'.format(str(hart[0].times[-1])[:19])
-        output += 'r1: {:>6.0f}, b1: {:>6.1f}\n'.format(
-            hart[0].values[-1], hart[1].values[-1])
-        # output += 'r2: {:>6.0f}, b2: {:>6.1f}\n'.format(
-        #  hart[1].values[-1], hart[3].values[-1])
-        output += 'Average Move: {:>6.0f}\n'.format(hart[2].values[-1])
-        # output += 'SP1: {:>6.0f}, SP2: {:>6.0f}\n'.format(
-        # hart[4].values[-1], hart[5].values[-1])
-        output += 'R Residuals: {:>6.0f}\n'.format(hart[3].values[-1])
-        # output += 'SP1: {:>6.0f}, SP2: {:>6.0f}\n'.format(
-        # hart[10].values[-1], hart[11].values[-1])
-        output += 'B Residuals: {:>6.1f}\n'.format(hart[4].values[-1])
-        # output += 'SP1: {:>6.1f}, SP2: {:>6.1f}\n'.format(
-        # hart[6].values[-1], hart[7].values[-1])
-        output += 'SP1 Temperature: {:>6.1f}\n'.format(hart[5].values[-1])
-        # output += 'SP1: {:>6.1f}, SP2: {:>6.1f}'.format(
-        # hart[8].values[-1], hart[9].values[-1])
+    def hartmann_parse(self, time):
+        output = '{}\n'.format(time.isot[:19])
+        inputs = []
+        for key in ["r1PistonMove_steps", "b1RingMove", "sp1AverageMove_steps",
+                    "sp1Residuals_deg", "sp1Temp_median"]:
+            time_delta =(self.support["harts"]['t' + key] - time).sec
+            x = self.support["harts"][key][(time_delta < 120)
+                                           & (time_delta > 0)]
+            if len(x) == 0:
+                inputs.append(np.nan)
+            else:
+                inputs.append(x[-1])
+        output += f"r1 Steps: {inputs[0]:>5.0f}, b1 Ring: {inputs[1]:>4.1f}\n"
+        output += f"Average Move:{inputs[2]:>5.0f}, Residuals:"
+        output += f" {inputs[3]:>4.1f}, Temp: {inputs[4]:>4.1f}\n"
         return output
 
     def p_summary(self):
         print('=' * 80)
         print('{:^80}'.format('Observing Summary'))
         print('=' * 80)
-        for i, design in enumerate(self.data['dDesign']):
+        for i, field in enumerate(self.data['dField']):
             print('')
-            print("Design {}, Config {}, {}, {}".format(design,
-                                                        self.data['dConfig'][i],
-                                                        self.design_data['dAPSummary'][i],
-                                                        self.design_data['dBSummary'][i]))
+            designs = ', '.join([f"{x:.0f}" for x in self.data['dDesign'][i]])
+            configs = ', '.join([f"{x:.0f}" for x in self.data['dConfig'][i]])
+            plurald = 's' if len(self.data["dDesign"][i]) > 1 else ''
+            pluralc = 's' if len(self.data["dConfig"][i]) > 1 else ''
+            print('\n'.join(textwrap.wrap(
+                f"Field {field:.0f} Design{plurald} {designs},"
+                f" Config{pluralc} {configs},"
+                f" {self.design_data['dAPSummary'][i]},"
+                f" {self.design_data['dBSummary'][i]}", 80)))
         print()
         if len(self.ap_data["fRatio"]) > 0:
             flux_ratio = np.nanmean(np.array(self.ap_data["fRatio"]), axis=0)
@@ -566,8 +532,8 @@ class Logging:
                 faint_bundles = self.ap_image.create_bundles(i_faint)
                 print("APOGEE Dome Flats\n"
                       f"Missing Fibers: {missing_bundles}\n"
-                      f" Faint fibers: {faint_bundles}\n"
-                      f" Average Throughput: {avg:.3f}")
+                      f"Faint fibers: {faint_bundles}\n"
+                      f"Average Throughput: {avg:.3f}")
                 print()
             else:
                 print("No APOGEE Dome Flats")
@@ -600,33 +566,41 @@ class Logging:
                 window = ((data['iTime'] >= data['dTime'][i])
                           & (data['iTime'] < Time.now() + 0.3)
                           & (data["iDesign"][i] == design)
-                         )
+                          )
             except IndexError:
                 window = np.array([False] * len(data['iTime']))
 
         return window
 
     def p_data(self):
+        start = Time(self.args.sjd - 0.3, format='mjd')
+        end = Time(self.args.sjd + 1, format='mjd') - 0.3
+        end = Time.now() if Time.now() < end else end
+        tel = log_support.LogSupport(start, end, self.args)
+        tel.get_hartmann(self.support)
+
         print('=' * 80)
         print('{:^80}'.format('Data Log'))
         print('=' * 80 + '\n')
-        for i, design in enumerate(self.data['dDesign']):
-            print('### Design {}\n'.format(design))
-            if design in self.ap_data['dDesign']:
-                ap_design = np.where(design == self.ap_data['dDesign'])[0][0]
+        for i, field in enumerate(self.data['dField']):
+            print('### Field {}\n'.format(field))
+            if field in self.ap_data['dField']:
+                ap_design = np.where(field == self.ap_data['dField'])[0][0]
 
                 print('# APOGEE')
-                print('{:<5} {:<8} {:<6} {:<8} {:<12} {:<4} {:<6} {:<5}'
-                      ' {:<4}'.format('MJD', 'UTC', "Config", 'Exposure', 'Type',
+                print('{:<5} {:<8} {:>}-{:<6} {:<8} {:<12} {:<4} {:<6} {:<5}'
+                      ' {:<4}'.format('MJD', 'UTC', "Design", "Config",
+                                      'Exposure', 'Type',
                                       'Dith', 'Reads', 'Arch',
                                       'Seeing'))
                 print('-' * 80)
                 # window = self.get_window(self.ap_data, ap_design, design)
-                window = self.ap_data["iDesign"] == design
-                for (mjd, iso, conf, exp_id, exp_type, dith, nread,
+                window = self.ap_data["iField"] == field
+                for (mjd, iso, des, conf, exp_id, exp_type, dith, nread,
                      detectors, see) in zip(
                     self.ap_data['iTime'][window].mjd + 0.3,
                     self.ap_data['iTime'][window].iso,
+                    self.ap_data["iDesign"][window],
                     self.ap_data["iConfig"][window],
                     self.ap_data['iID'][window],
                     self.ap_data['iEType'][window],
@@ -635,15 +609,15 @@ class Logging:
                     self.ap_data['iDetector'][window],
                     self.ap_data['iSeeing'][window]
                 ):
-                    print('{:<5.0f} {:0>8} {:>6.0f} {:<8.0f} {:<12} {:<4} {:>5}'
-                          ' {:<5}'
-                          ' {:>4.1f}'.format(int(mjd), iso[11:19], conf, exp_id,
-                                             exp_type,
+                    print('{:<5.0f} {:0>8} {:>6.0f}-{:<6.0f} {:<8.0f} {:<12}'
+                          ' {:<4} {:>5} {:<5}'
+                          ' {:>4.1f}'.format(int(mjd), iso[11:19], des, conf,
+                                             exp_id, exp_type,
                                              dith, nread, detectors, see))
                 print()
-                if design in self.ap_data['dDesign']:
-                    for j, dome in enumerate(self.ap_data['fDesign']):
-                        if dome == design:
+                if field in self.ap_data['dField']:
+                    for j, dome in enumerate(self.ap_data['fField']):
+                        if dome == field:
                             print(self.ap_data['fTime'][j].iso)
                             print(textwrap.fill('Missing fibers: {}'.format(
                                 self.ap_data['fMissing'][j]), 80))
@@ -653,62 +627,50 @@ class Logging:
                                   f" {np.nanmean(self.ap_data['fRatio'][j]):.2f}")
                             print()
 
-            if design in self.b_data['dDesign']:
+            if field in self.b_data['dField']:
                 print('# BOSS')
-                print('{:<5} {:<8} {:<6} {:<8} {:<7} {:<4} {:<11} {:<5} {:<5}'
-                      ''.format('MJD', 'UTC', "Config", 'Exposure', 'Type',
-                                'Dith', 'SOS', 'ETime', 'Hart'))
+                print('{:<5} {:<8} {:>6}-{:<6} {:<8} {:<7} {:<5} {:<5} {:<5}'
+                      ''.format('MJD', 'UTC', "Design", "Config", 'Exposure',
+                                'Type', 'SOS', 'ETime', 'Hart'))
                 print('-' * 80)
                 # i is an index for data, but it will disagree with b_data
                 # if there is an apogee-onlydesign
-                b_design = np.where(design == self.b_data['dDesign'])[0][0]
+                b_field = np.where(field == self.b_data['dField'])[0][0]
                 # window = self.get_window(self.b_data, b_design, design)
-                window = self.b_data["iDesign"] == design
-                for (mjd, iso, conf, exp_id, exp_type, dith,
+                window = self.b_data["iField"] == field
+                for (mjd, iso, design, conf, exp_id, exp_type,
                      detectors, etime, hart) in zip(
                     self.b_data['iTime'][window].mjd + 0.3,
                     self.b_data['iTime'][window].iso,
+                    self.b_data["iDesign"][window],
                     self.b_data["iConfig"][window],
                     self.b_data['iID'][window],
                     self.b_data['iEType'][window],
-                    self.b_data['iDither'][window],
                     self.b_data['iDetector'][window],
                     self.b_data['idt'][window],
                     self.b_data['iHart'][window],
                 ):
-                    print('{:<5.0f} {:0>8} {:>6.0f} {:0>8.0f} {:<7} {:<4} {:<11}'
+                    print('{:<5.0f} {:0>8} {:>6.0f}-{:<6.0f} {:0>8.0f} {:<7}'
+                          ' {:<5}'
                           ' {:>5.0f} {:<5}'
-                          ''.format(int(mjd), iso[11:19], conf, exp_id,
-                                    exp_type.strip(),
-                                    dith.strip(), detectors, etime,
+                          ''.format(int(mjd), iso[11:19], design, conf, exp_id,
+                                    exp_type.strip(), detectors, etime,
                                     hart))
-                #try:
-                #    window = ((self.b_data['hTime']
-                #               >= self.data['dTime'][i])
-                #              & (self.b_data['hTime']
-                #                 < self.data['dTime'][i + 1])
-                #              )
-                #except IndexError:
-                #    window = ((self.b_data['hTime']
-                #               >= self.data['dTime'][i])
-                #              & (self.b_data['hTime'] < Time.now()))
-                #if self.b_data['hTime'][window]:
-                #    print()
-                #    # print('Hartmanns')
-                #for t, hart in zip(self.b_data['hTime'][window],
-                #                   self.b_data['hHart'][window]):
-                #    print(self.hartmann_parse(hart))
+                hwindow = self.b_data["hField"] == field
+                for t in self.b_data["hTime"][hwindow]:
+                    print(self.hartmann_parse(t))
                 print()
 
     def p_boss(self):
         print('=' * 80)
         print('{:^80}'.format('BOSS Data Summary'))
         print('=' * 80 + '\n')
-        print('{:<5} {:<8} {:<13} {:<8} {:<7} {:<4} {:<11} {:<5} {:<5}'
-              ''.format('MJD', 'UTC', 'Design-Config', 'Exposure', 'Type', 'Dith',
+        print('{:<5} {:<8} {:<13} {:<8} {:<7} {:<5} {:<5} {:<5}'
+              ''.format('MJD', 'UTC', 'Design-Config', 'Exposure', 'Type',
                         'SOS', 'ETime', 'Hart'))
         print('-' * 80)
-        for (mjd, iso, design, design, config, exp_id, exp_type, dith, detectors, etime,
+        for (mjd, iso, design, design, config, exp_id, exp_type, 
+             detectors, etime,
              hart) in zip(self.b_data['iTime'].mjd + 0.3,
                           self.b_data['iTime'].iso,
                           self.b_data['iDesign'],
@@ -716,16 +678,14 @@ class Logging:
                           self.b_data['iConfig'],
                           self.b_data['iID'],
                           self.b_data['iEType'],
-                          self.b_data['iDither'],
                           self.b_data['iDetector'],
                           self.b_data['idt'],
                           self.b_data['iHart']):
-            print('{:<5.0f} {:>8} {:>6}-{:<6.0f} {:0>8.0f} {:<7} {:<4}'
-                  ' {:<11}'
+            print('{:<5.0f} {:>8} {:>6}-{:<6.0f} {:0>8.0f} {:<7} '
+                  ' {:<5}'
                   ' {:>5.0f} {:<5}'
                   ''.format(int(mjd), iso[11:19], design, config, exp_id,
-                            exp_type.strip(),
-                            dith.strip(), detectors, etime, hart))
+                            exp_type.strip(), detectors, etime, hart))
         print()
 
     def p_apogee(self):
@@ -796,7 +756,8 @@ class Logging:
         print('\n'.join(wrapper.wrap(une_str)))
         if len(self.ap_data['oOffset']) > 1:
             # Put it under an if in case we didn't open.
-            did_move = self.ap_data["oDither"][:-1] != self.ap_data["oDither"][1:]
+            did_move = self.ap_data["oDither"][:-
+                                               1] != self.ap_data["oDither"][1:]
             rel_offsets = np.abs(self.ap_data['oOffset'][1:][did_move]
                                  - self.ap_data["oOffset"][:-1][did_move])
             obj_str = ('Object Offsets: Max: {:.2f}, Min: {:.2f}, Mean: {:.2f}'
@@ -823,30 +784,32 @@ class Logging:
         start = Time(self.args.sjd - 0.3, format='mjd')
         end = Time(self.args.sjd + 1, format='mjd') - 0.3
         end = Time.now() if Time.now() < end else end
-        tel = log_support.LogSupport(start, end, self.args)
-        support = multiprocessing.Manager().dict()
-        tel.set_callbacks()
-        offsets = multiprocessing.Process(target=tel.get_offsets,
-                                          args=(support,))
-        focus = multiprocessing.Process(target=tel.get_focus,
-                                          args=(support,))
-        weather = multiprocessing.Process(target=tel.get_weather,
-                                          args=(support,))
-        hartmann = multiprocessing.Process(target=tel.get_hartmann,
-                                           args=(support,))
+        sup = log_support.LogSupport(start, end, self.args)
+        sup.set_callbacks()
+        offsets = multiprocessing.Process(target=sup.get_offsets,
+                                          args=(self.support,))
+        focus = multiprocessing.Process(target=sup.get_focus,
+                                        args=(self.support,))
+        weather = multiprocessing.Process(target=sup.get_weather,
+                                          args=(self.support,))
+        if "harts" not in self.support.keys():
+            hartmann = multiprocessing.Process(target=sup.get_hartmann,
+                                               args=(self.support,))
+            hartmann.start()
         offsets.start()
         focus.start()
         weather.start()
-        hartmann.start()
-        offsets.join(10)
-        focus.join(10)
-        weather.join(10)
-        hartmann.join(10)
-        print(support["offsets"])
-        print(support["focus"])
-        print(support["weather"])
-        print(support["hartmann"])
-        
+        # If these queries are timing out, you have an issue in Influx
+        offsets.join(8)
+        focus.join(8)
+        weather.join(8)
+        if "harts" not in self.support.keys():
+            hartmann.join(5)
+        print(self.support["offsets"])
+        print(self.support["focus"])
+        print(self.support["weather"])
+        print(self.support["hartmann"])
+
     @staticmethod
     def mirror_numbers():
         print('=' * 80)
@@ -930,7 +893,7 @@ def main():
     except OSError:
         pass
     ap_images = Path(ap_data_dir).glob('apR-a*.apz')
-    
+
     b_images = Path(b_data_dir).glob('sdR-r1*fit.gz')
     try:
         for img in b_images:
