@@ -7,6 +7,7 @@ TODO: Thread these queries
 """
 import argparse
 import multiprocessing
+from tkinter import W
 
 import numpy as np
 
@@ -58,7 +59,7 @@ class LogSupport:
         self.tend = Time(tend)
         self.args = args
         if args.verbose:
-            print(f"Log Support Window: {self.tstart}-{self.tend}")
+            print(f"Log Support Window: {self.tstart.iso}-{self.tend.iso}")
 
         self.call_times = []
         self.offsets = ""
@@ -86,7 +87,8 @@ class LogSupport:
         enclosure.join(5)
         try:
             all_times = Time(callback_dict["boss_calls"]
-                             + callback_dict["apogee_calls"])
+                             + callback_dict["apogee_calls"]
+                             + callback_dict["enclosure_times"])
         except ValueError:
             self.call_times = []
             return
@@ -113,13 +115,19 @@ class LogSupport:
                 # 15 * 60 / 86400), format="mjd")
 
     def get_offsets(self, out_dict={}):
-        self.offsets = f"{'Time':<8} {'Az':<6} {'Alt':<4} {'Rot':<6}\n"
+        start = Time.now()
+        self.offsets = (f"{'Time':<8} {'Field':>6}-{'Design':<6} {'Az':>6}"
+            f" {'Alt':>4} {'Rot':>6} {'Az Off':>6} {'Alt Off':>7}"
+            f" {'Rot Off':>7} {'Guide RMS (um)':>14}\n")
         self.offsets += '=' * 80 + '\n'
         offsets_tab = {}
         offsets_tab_path = Path(__file__).parent.parent / "flux/offsets.flux"
         with offsets_tab_path.open('r') as fil:
+            pre_query = Time.now()
             off_tables = influx_fetch.query(fil.read(),
-                self.tstart, self.tend)
+                self.call_times[0], self.call_times[-1], interval="1m",
+                verbose=self.args.verbose)
+            post_query = Time.now()
         for table in off_tables:
             for row in table.records:
                 field = row.get_field()
@@ -129,6 +137,7 @@ class LogSupport:
                 else:
                     offsets_tab[f"t{field}"] = [row.get_time()]
                     offsets_tab[field] = [row.get_value()]
+        post_parse = Time.now()
         for key in offsets_tab.keys():
             if key[0] == 't':
                 offsets_tab[key] = Time(offsets_tab[key])
@@ -136,9 +145,13 @@ class LogSupport:
                 offsets_tab[key] = np.array(offsets_tab[key])
         if len(offsets_tab) == 0:
             return
+        post_sort = Time.now()
         for t in self.call_times:
             line = [t.isot[11:19]] 
-            for key in ["az", "alt", "rot"]:
+            for key in ["configuration_loaded_2", "configuration_loaded_1",
+                        "axePos_az", "axePos_alt", "axePos_rot",
+                        "objArcOff_0_P", "objArcOff_1_P", "guideOff_2_P",
+                        "guide_rms_3"]:
                 before = offsets_tab['t' + key] < t
                 if before.sum() == 0:
                     line.append(np.nan)
@@ -146,29 +159,37 @@ class LogSupport:
                     line.append(offsets_tab[key][before][-1])
             if np.all(np.isnan(np.array(line[1:]))):
                 continue
-            self.offsets += "{:<8} {:>6.1f} {:>4.1f} {:>6.1f}\n".format(*line)
+            self.offsets += ("{:<8} {:>6.0f}-{:<6.0f} {:>6.1f} {:>4.1f}"
+                             " {:>6.1f} {:>6.3f} {:>7.3f} {:>7.3f} {:>14.3f}"
+                             "\n".format(*line))
+        post_print = Time.now()
         out_dict["offsets"] = self.offsets        
+        if self.args.verbose:
+            times = Time([start, pre_query, post_query, post_parse, post_sort,
+                          post_print]) - start
+            print(f"Offsets overheads: {np.diff(times.sec)}")
 
     def get_focus(self, out_dict={}):
-        self.focus = (f"{'Time':<8} {'M1':<4} {'M2':<4} {'Focus':<5}"
-                      f" {'Az':<6} {'Alt':<5} {'Temp':<5} {'Wind':<4}"
-                      f" {'Dir':<3}\n")
+        self.focus = (f"{'Time':<8} {'Field':>6}-{'Design':<6} {'M1':>7}"
+                      f" {'M2':>7} {'Focus':>5}"
+                      f" {'Az':>6} {'Alt':>5} {'Temp':>5} {'Wind':>4}"
+                      f" {'Dir':>3}\n")
         self.focus += '=' * 80 + '\n'
         focus_tab = {}
         focus_tab_path = Path(__file__).parent.parent / "flux/focus.flux"
         with focus_tab_path.open('r') as fil:
             off_tables = influx_fetch.query(fil.read(),
-                self.tstart, self.tend)
+                self.call_times[0], self.call_times[-1], interval="1m",
+                verbose=self.args.verbose)
         for table in off_tables:
             for row in table.records:
-                measurement = row.get_measurement()
-                measurement = measurement if measurement != "axePos" else row.get_field()
-                if measurement in focus_tab.keys():
-                    focus_tab[f"t{measurement}"].append(row.get_time())
-                    focus_tab[measurement].append(row.get_value())
+                field = row.get_field()
+                if field in focus_tab.keys():
+                    focus_tab[f"t{field}"].append(row.get_time())
+                    focus_tab[field].append(row.get_value())
                 else:
-                    focus_tab[f"t{measurement}"] = [row.get_time()]
-                    focus_tab[measurement] = [row.get_value()]
+                    focus_tab[f"t{field}"] = [row.get_time()]
+                    focus_tab[field] = [row.get_value()]
         for key in focus_tab.keys():
             if key[0] == 't':
                 focus_tab[key] = Time(focus_tab[key])
@@ -176,8 +197,10 @@ class LogSupport:
                 focus_tab[key] = np.array(focus_tab[key])
         for t in self.call_times:
             line = [t.isot[11:19]] 
-            for key in ["primOrient", "secOrient", "secFocus", "az", "alt",
-                        "airTempPT", "winds", "windd"]:
+            for key in ["configuration_loaded_2", "configuration_loaded_1",
+                        "primOrient_pos", "secOrient_piston", "secFocus",
+                        "axePos_az",
+                        "axePos_alt", "airTempPT", "winds", "windd"]:
                 if 't' + key in focus_tab.keys():
                     before = focus_tab['t' + key] < t
                     if before.sum() == 0:
@@ -188,7 +211,8 @@ class LogSupport:
                     line.append(np.nan)
             if np.all(np.isnan(np.array(line[1:]))):
                 continue
-            self.focus += ("{:<8} {:>4.0f} {:>4.0f} {:>5.0f} {:>6.1f} {:>5.1f}"
+            self.focus += ("{:<8} {:>6.0f}-{:<6.0f} {:>7.2f} {:>7.2f} {:>5.0f}"
+                           " {:>6.1f} {:>5.1f}"
                            " {:>5.1f} {:>4.0f} {:>3.0f}\n".format(
                                  *line))
         out_dict["focus"] = self.focus
@@ -197,30 +221,31 @@ class LogSupport:
         dust = "1\u03BCm Dust"
         irscs = "IRSC \u03C3"
         irscm = "IRSC \u03BC"
-        self.weather = (f"{'Time':<8} {'Temp':<5} {'DP':<5} {'Diff':<5}"
-            f" {'Humid':<5} {'Wind':<5} {'Dir':<3} {dust:<8}"
-            f" {irscs:<6} {irscm:<6}\n")
+        self.weather = (f"{'Time':<8} {'Field':>6}-{'Design':<6} {'Temp':>5}"
+                        f" {'DP':>5} {'Diff':>5}"
+            f" {'Humid':>5} {'Wind':>5} {'Dir':>3} {dust:>8}"
+            f" {irscs:>6} {irscm:>6}\n")
         self.weather += '=' * 80 + '\n'
         weather_tab = {}
         weather_tab_path = Path(__file__).parent.parent / "flux/weather.flux"
         with weather_tab_path.open('r') as fil:
-            off_tables = influx_fetch.query(fil.read(),
-                self.tstart, self.tend)
-        for table in off_tables:
+            weather_tables = influx_fetch.query(fil.read(),
+                self.call_times[0], self.call_times[-1], interval="1m",
+                verbose=self.args.verbose)
+        for table in weather_tables:
             for row in table.records:
-                measurement = row.get_measurement()
-                if measurement in weather_tab.keys():
-                    weather_tab[f"t{measurement}"].append(row.get_time())
-                    weather_tab[measurement].append(row.get_value())
+                field = row.get_field()
+                if field in weather_tab.keys():
+                    weather_tab[f"t{field}"].append(row.get_time())
+                    weather_tab[field].append(row.get_value())
                 else:
-                    weather_tab[f"t{measurement}"] = [row.get_time()]
-                    weather_tab[measurement] = [row.get_value()]
+                    weather_tab[f"t{field}"] = [row.get_time()]
+                    weather_tab[field] = [row.get_value()]
                     
         # Filter out dpDep values by adding a fake value every time the humidity
         # is above 90
         for i, h in enumerate(weather_tab["humidPT"]):
             if h > 90:
-                # print(weather_tab["thumidPT"][i], h)
                 weather_tab["dustb"].append(np.nan)
                 weather_tab["tdustb"].append(weather_tab["thumidPT"][i])
         for key in weather_tab.keys():
@@ -237,8 +262,9 @@ class LogSupport:
             weather_tab["tdustb"].argsort()]
         for t in self.call_times:
             line = [t.isot[11:19]] 
-            for key in ["airTempPT", "airTempPT", "dpTempPT", "humidPT", "winds", "windd",
-                        "dustb", "irscsd", "irscmean"]:
+            for key in ["configuration_loaded_2", "configuration_loaded_1",
+                        "airTempPT", "airTempPT", "dpTempPT", "humidPT",
+                        "winds", "windd", "dustb", "irscsd", "irscmean"]:
                 if 't' + key in weather_tab.keys():
                     before = weather_tab['t' + key] < t
                     if before.sum() == 0:
@@ -253,58 +279,75 @@ class LogSupport:
                 
             if np.all(np.isnan(np.array(line[1:]))):
                 continue
-            self.weather += ("{:<8} {:>5.1f} {:>5.1f} {:>5.1f} {:>5.1f} {:>5.1f}"
+            self.weather += ("{:<8} {:>6.0f}-{:<6.0f} {:>5.1f} {:>5.1f}"
+                             " {:>5.1f} {:>5.1f} {:>5.1f}"
                              " {:>3.0f} {:>8.0f} {:>6.1f} {:>6.0f}\n".format(
                                  *line))
         out_dict["weather"] = self.weather
 
     def get_hartmann(self, out_dict={}):
-        self.hartmann = f"{'Time':8} {'Temp':<6} {'R off':<6} {'B off':<6}"
-        self.hartmann += f" {'Move':<6} {'Resid':<6}\n"
+        self.hartmann = (f"{'Time':8} {'Field':>6}-{'Design':<6} {'Temp':>6}"
+                         f" {'R off':>6} {'B off':>6} {'Move':>6} {'Resid':>6}"
+                         " \n")
         self.hartmann += '=' * 80 + '\n'
-        harts = {}
+        self.harts = {}
         boss_temps = []
         boss_times = []
         hartmanns_path = Path(__file__).parent.parent / "flux/hartmanns.flux"
-        boss_temps_path = Path(__file__).parent.parent / "flux/boss_temps.flux"
+        # boss_temps_path = Path(__file__).parent.parent / "flux/boss_temps.flux"
         with hartmanns_path.open('r') as fil:
             hart_tables = influx_fetch.query(fil.read(),
-                self.tstart, self.tend)
-        with boss_temps_path.open('r') as fil:
-            boss_tables = influx_fetch.query(fil.read(),
-                self.tstart, self.tend)
-        if len(boss_tables) == 0 or len(hart_tables) == 0:
+                self.tstart, self.tend,
+                verbose=self.args.verbose)
+        # with boss_temps_path.open('r') as fil:
+            # boss_tables = influx_fetch.query(fil.read(),
+                # self.tstart, self.tend)
+        if len(hart_tables) == 0:
             return
-        for table in boss_tables:
-            for row in table.records:
-                boss_times.append(row.get_time()) 
-                boss_temps.append(row.get_value())
+        # for table in boss_tables:
+            # for row in table.records:
+                # boss_times.append(row.get_time()) 
+                # boss_temps.append(row.get_value())
         for table in hart_tables:
             for row in table.records:
-                if row.get_measurement() in harts.keys():
-                    harts[f"t{row.get_measurement()}"].append(row.get_time())
-                    harts[row.get_measurement()].append(row.get_value())
+                if row.get_field() in self.harts.keys():
+                    self.harts[f"t{row.get_field()}"].append(row.get_time())
+                    self.harts[row.get_field()].append(row.get_value())
                 else:
-                    harts[f"t{row.get_measurement()}"] = [row.get_time()]
-                    harts[row.get_measurement()] = [row.get_value()]
-        for key in harts.keys():
+                    self.harts[f"t{row.get_field()}"] = [row.get_time()]
+                    self.harts[row.get_field()] = [row.get_value()]
+        for key in self.harts.keys():
             if key[0] == 't':
-                harts[key] = Time(harts[key])
+                self.harts[key] = Time(self.harts[key])
             else:
-                harts[key] = np.array(harts[key])
-        boss_times = Time(boss_times)
-        boss_temps = np.array(boss_temps)
-        for t in harts["tsp1Residuals"]:
+                self.harts[key] = np.array(self.harts[key])
+        # boss_times = Time(boss_times)
+        # boss_temps = np.array(boss_temps)
+        for t in self.harts["tsp1Residuals_deg"]:
             line = [t.isot[11:19]]
-            last_temp_filt = boss_times < t
-            line.append(boss_temps[last_temp_filt][-1])
-            for key in ["r1PistonMove", "b1RingMove",
-                        "sp1AverageMove", "sp1Residuals"]:
-                in_window = np.abs(harts['t' + key] - t) < 10 / 86400
-                line.append(harts[key][in_window][0])
-            self.hartmann += ("{:8} {:>6.1f} {:>6.0f} {:>6.1f} {:>6.0f}"
+            # last_temp_filt = boss_times < t
+            # line.append(boss_temps[last_temp_filt][-1])
+            for key in ["configuration_loaded_2", "configuration_loaded_1",
+                        "sp1Temp_median",
+                        "r1PistonMove_steps", "b1RingMove",
+                        "sp1AverageMove_steps", "sp1Residuals_deg"]:
+                if 't' + key in self.harts.keys():
+                    if ("configuration_loaded" in key) or ("sp1Temp" in key):
+                        before = self.harts['t' + key] < t
+                        if before.sum() == 0:
+                            line.append(np.nan)
+                        else:
+                            line.append(self.harts[key][before][-1])
+                    else:
+                        in_window = np.abs(self.harts['t' + key] - t) < 10 / 86400
+                        line.append(self.harts[key][in_window][0])
+                else:
+                    line.append(np.nan)
+            self.hartmann += ("{:8} {:>6.0f}-{:<6.0f} {:>6.1f} {:>6.0f}"
+                              " {:>6.1f} {:>6.0f}"
                               " {:>6.1f}\n".format(*line))
         out_dict["hartmann"] = self.hartmann
+        out_dict["harts"] = self.harts
 
 def main():
     parser = argparse.ArgumentParser()
